@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp;
 use vars qw($VERSION);
-$VERSION = '0.07';
+$VERSION = '0.08';
 
 use Crypt::Rijndael;
 use Digest::MD5;
@@ -90,7 +90,7 @@ Audio::M4P::Decrypt -- DRMS decryption of Apple iTunes style MP4 player files
 
 =head1 DESCRIPTION
     
-Derivation from the DeDRMS.cs program by Jon Lech Johansen
+Originally derived from the DeDRMS.cs program by Jon Lech Johansen
 
 =head1 SYNOPSIS
 
@@ -152,17 +152,9 @@ More descriptive alias for the B<DeDRMS> method.
     use of digital music files by parties other than the purchaser of the 
     originally DRM-protected material. That is Fair Use, corporate entities. 
 
-    From Jon Lech Johansen:
-
-        DeDRMS requires that you already have the user key file(s) for
-        your files. The user key file(s) can be generated by playing
-        your files with the VideoLAN Client [1][2].
-    [1] http://www.videolan.org/vlc/ [videolan.org]
-    [2] http://wiki.videolan.org/tiki-read_article.php?articleId=5 [videolan.org]
-
     Note that later versions of iTunes are not compatible with vlc's key finding;
-    for locating keys, look for compatible versions of FairKeys or use the 
-    LWP::UserAgent::iTMS_Client Perl module when available.
+    for locating keys, look for compatible versions of Johansen's FairKeys or 
+    use the LWP::UserAgent::iTMS_Client Perl module when available.
 
 =head1 AUTHOR 
 
